vexmpp\.suelta package
======================

Subpackages
-----------

.. toctree::

    vexmpp.suelta.mechanisms

Submodules
----------

vexmpp\.suelta\.exceptions module
---------------------------------

.. automodule:: vexmpp.suelta.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.suelta\.sasl module
---------------------------

.. automodule:: vexmpp.suelta.sasl
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.suelta\.saslprep module
-------------------------------

.. automodule:: vexmpp.suelta.saslprep
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.suelta\.util module
---------------------------

.. automodule:: vexmpp.suelta.util
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: vexmpp.suelta
    :members:
    :undoc-members:
    :show-inheritance:
